pub fn server_header() -> HeaderValueExpand description
Returns the default server header value for trillium, including both the
trillium and trillium-http crate versions.
The contents are necessarily unconstrained by semver.
pub fn server_header() -> HeaderValueReturns the default server header value for trillium, including both the
trillium and trillium-http crate versions.
The contents are necessarily unconstrained by semver.